# 自媒体维基广告投放页面

## 项目简介
这是一个基于访问量动态定价的广告投放系统，专为自媒体维基网站设计。系统能够根据网站实时访问量自动调整广告位价格，为广告主提供透明、公平的广告投放服务。

## 技术架构
### 前端技术栈
- HTML5：页面结构
- CSS3：样式设计
- JavaScript：交互逻辑
- WebP：图片格式（优化加载速度）

### 核心功能模块
1. **动态定价系统**
   - 基于访问量的价格计算
   - 自动价格更新机制
   - 多种支付方式支持

2. **广告位管理**
   - 多类型广告位支持
   - 预订状态管理
   - 图片预览功能

3. **数据统计**
   - 实时访问量统计
   - 价格系数计算
   - 预订状态追踪

## 文件结构
```
project/
├── index.html          # 主页面
├── styles.css          # 样式文件
├── script.js           # 核心逻辑
├── info.php           # 访问量数据接口（需要自己写一个数据获取API）
└── images/            # 图片资源目录
```

## 核心配置说明

### 1. 广告位配置 (script.js)
```javascript
const AD_POSITIONS = {
    'ad-id': {
        id: 'ad-id',           // 广告位唯一标识
        title: '广告位标题',    // 显示标题
        image: '图片URL',      // 预览图片
        dimensions: '尺寸',     // 广告位尺寸
        prices: {
            monthly: 价格,     // 月付价格
            yearly: 价格       // 年付价格
        }
    }
};
```

### 2. 访问量价格系数 (script.js)
```javascript
const VISIT_COEFFICIENTS = {
    'low': { min: 0, max: 30000, coefficient: 0.8 },     // 低访问量，价格打8折
    'medium': { min: 30001, max: 60000, coefficient: 1 }, // 中等访问量，原价
    'high': { min: 60001, max: 100000, coefficient: 1.2 }, // 高访问量，价格上浮20%
    'veryHigh': { min: 100001, max: Infinity, coefficient: 1.5 } // 极高访问量，价格上浮50%
};
```

### 3. 预订状态管理 (script.js)
```javascript
const BOOKED_STATUS = {
    'ad-id': {
        isBooked: true/false,  // 是否已预订
        endDate: '到期时间'    // ISO格式的到期时间
    }
};
```

## 维护指南

### 1. 添加新广告位
1. 在 `AD_POSITIONS` 中添加新配置
2. 在 `BOOKED_STATUS` 中添加状态管理
3. 确保图片资源已上传

### 2. 修改价格系数
1. 编辑 `VISIT_COEFFICIENTS` 对象
2. 调整各访问量区间的系数
3. 系统会自动应用新的价格计算规则

### 3. 更新预订状态
1. 修改 `BOOKED_STATUS` 中的状态
2. 设置 `isBooked` 为 true/false
3. 更新 `endDate` 为新的到期时间

### 4. 图片资源管理
1. 使用 WebP 格式优化加载速度
2. 图片尺寸建议：
   - Banner广告：1200×200px
   - 侧边栏广告：300×600px
   - 分类页广告：800×150px
   - 文末广告：600×300px
   - 网址推荐：800×100px

## 数据接口说明

### 访问量数据接口 (info.php)
```php
// 返回格式
{
    "today_uv": 今日UV,
    "today_pv": 今日PV,
    "yesterday_uv": 昨日UV,
    "yesterday_pv": 昨日PV,
    "last_month_pv": 上月PV,
    "last_year_pv": 去年PV
}
```

## 价格计算规则
1. 基础价格 × 访问量系数 = 实际价格
2. 访问量系数根据月PV自动调整
3. 价格每5分钟自动更新一次

## 预订流程
1. 用户选择广告位
2. 系统计算实际价格
3. 用户确认预订
4. 更新预订状态
5. 显示预订成功信息

## 注意事项
1. 确保 info.php 接口正确返回访问量数据
2. 定期检查图片资源是否可用
3. 及时更新预订状态
4. 保持价格系数的合理性

## 更新日志
### 2024-02-29
- 初始版本发布
- 实现动态定价系统
- 添加广告位预览功能
- 优化移动端显示效果

## 未来计划

可在线支付的自助广告系统

绑定对应广告位的动态码

实现全程自助下单并完成广告投放

## 版权信息
© 2025 自媒体维基. All rights reserved.